httplib.HTTPResponse

Module httplib :: Class HTTPResponse |
[show private | hide private]
[frames | no frames]

## Class HTTPResponse

Method Summary
| `__init__(self, sock, debuglevel, strict, method)`
| `begin(self)`
| `close(self)`
| `getheader(self, name, default)`
| `isclosed(self)`
| `read(self, amt)`
| `_check_close(self)`
| `_read_chunked(self, amt)`
| `_read_status(self)`
| ``_safe_read`(self, amt)` Read the number of bytes requested, compensating for partial reads.

Method Details

### _safe_read(self, amt) Read the number of bytes requested, compensating for partial reads. Normally, we have a blocking socket, but a read() can be interrupted by a signal (resulting in a partial read). Note that we cannot distinguish between EOF and an interrupt when zero bytes have been read. IncompleteRead() will be raised in this situation. This function should be used when <amt> bytes "should" be present for reading. If the bytes are truly not available (due to EOF), then the IncompleteRead exception can be used to detect the problem.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net